#include <stdbool.h>
#include <stdint.h>
#include <Energia.h>
#include <Wire.h>
#include "Melody_HDC1080.h"

CMelodyHDC1080::CMelodyHDC1080()
{

}

/***************************************************************************
 * @brief:  读取数据
 * @param： regaddress:寄存器地址
 * @return: 读取的数据
 ***************************************************************************/
uint16_t CMelodyHDC1080::read(uint8_t regaddress)
{
    uint16_t data = 0;
    Wire.beginTransmission(HDC_ADDRESS);
    Wire.write(regaddress);
    Wire.endTransmission();

    delay(40);

    Wire.requestFrom(HDC_ADDRESS,2);
    if(Wire.available() >= 2)
    {
        data = Wire.read() << 8;
        data |= Wire.read();
    }
    return data;
}

/****************************************************************************
 * @brief:  写数据
 * @param： regaddress：寄存器地址
 *          pdata，指向需要写入数据的指针
 *          length，数据长度
 * @return： none 
 ***************************************************************************/
void CMelodyHDC1080::write(uint8_t regaddress,uint8_t *pdata,uint8_t length)
{
    Wire.beginTransmission(HDC_ADDRESS);
    Wire.write(regaddress);
    Wire.write(pdata,length);
    Wire.endTransmission();
}

/****************************************************************************
 * @brief:  初始化配置
 * @param：  none
 * @return： none
 ****************************************************************************/
void CMelodyHDC1080::begin()
{
    Wire.begin();

    uint8_t confdata[2] = {0};
    confdata[0] = (HDC_CONFIGURATION >> 8) & 0xFF;
    confdata[1] = HDC_CONFIGURATION & 0xFF;

    write(HDCREG_CONFIGURATION,confdata,2);
}

/****************************************************************************
 * @brief:  读取温度
 * @param：  none
 * @return: 温度值
 ****************************************************************************/
float CMelodyHDC1080::getTemperature()
{
    uint16_t temperature = 0;
    temperature = read(HDCREG_TEMPERATURE);

    return (temperature / 65536.0 * 165.0 - 40.0);
}

/****************************************************************************
 * @brief:  读取相对湿度
 * @param：  none
 * @return: 相对湿度数据
 ****************************************************************************/
float CMelodyHDC1080::getHumidity()
{
    uint16_t humidity = 0;
    humidity = read(HDCREG_HUMIDITY);

    return (humidity / 65536.0 * 100.0);
}

/****************************************************************************
 * @brief:  读取Manufacturer ID
 * @param：none
 * @return: Manufacturer ID
 ****************************************************************************/
uint16_t CMelodyHDC1080::getManufacturerID()
{
    return read(HDCREG_MANUFACTURERID);
}

/*****************************************************************************
 * @brief:  读取Device ID
 * @param：  none
 * @return： none
 *****************************************************************************/
uint16_t CMelodyHDC1080::getDeviceID()
{
    return read(HDCREG_DEVICEID);
}

/******************************************************************************
 * @brief:  读取Serial ID
 * @param：  pdata,指向存放SerialID的指针
 *            length，数据长度
 * @return： 返回pdata
 ******************************************************************************/
uint16_t* CMelodyHDC1080::getSerialID(uint16_t *pdata,uint8_t length)
{
    if(length < 3)
    {
        return NULL;
    }
    pdata[0] = read(HDCREG_SERIALID_FRIST);
    pdata[1] = read(HDCREG_SERIALID_MID);
    pdata[2] = read(HDCREG_SERIALID_LAST);

    return pdata;
}

CMelodyHDC1080 MelodyHDC1080;