#ifndef __MELODY_LDC1000_H__
#define __MELODY_LDC1000_H__

#define LDCREG_DEVICEID                 0x00                    //Device ID
#define LDCREG_RPMAX                    0x01                    //Rp_Max
#define LDCREG_RPMIN                    0x02                    //Rp_Min
#define LDCREG_SENSORFREQENCY           0x03                    //Sensor Frequency
#define LDCREG_LDCCONFIG                0x04                    //LDC Configuration
#define LDCREG_CLKCONFIG                0x05                    //Clock Configuration
#define LDCREG_THRESHOLDHIGH_LSB        0x06                    //Comparator Threshold High LSB
#define LDCREG_THRESHOLDHIGH_MSB        0x07                    //Comparator Threshold High MSB
#define LDCREG_THRESHOLDLOW_LSB         0x08                    //Comparator Threshold LOW LSB
#define LDCREG_THRESHOLDLOW_MSB         0x09                    //Comparator Threshold LOW MSB
#define LDCREG_INTCONFIG                0x0A                    //INTB Pin Configuration
#define LDCREG_PWRCONFIG                0x0B                    //Power Configuration
#define LDCREG_STATUS                   0x20                    //Status
#define LDCREG_PROXIMITY_LSB            0x21                    //Proximity Data LSB
#define LDCREG_PROXIMITY_MSB            0x22                    //Proximity Data MSB
#define LDCREG_FREQUENCYCTR_LSB         0x23                    //Frequency Counter Data LSB
#define LDCREG_FREQUENCYCTR_MID         0x24                    //Frequency Counter Data Mid-Byte
#define LDCREG_FREQUENCYCTR_MSB         0x25                    //Frequency Counter Data MSB

#define LDCVALUE_SENSORFREQENCY         0xD1                    //Sensor Frequency Value
#define LDCVALUE_LDCCONFIG              0x17                    //Amplitude:10,Response Time:111,0b10111=0x17
#define LDCVALUE_CLKCONFIG              0x02                    //CLK_SEL:1,CLK_PD:0 use External Crystal
#define LDCVALUE_INTCONFIG              0x04                    
#define LDCVALUE_THRESHOLDHIGH_LSB      0x50
#define LDCVALUE_THRESHOLDHIGH_MSB      0x14
#define LDCVALUE_THRESHOLDLOW_LSB       0xC0
#define LDCVALUE_THRESHOLDLOW_MSB       0x12
#define LDCVALUE_PWRCONFIG              0x01                    //Active Mode Conversion is Enable

#define LDCVALUE_RPMAX                  0x13
#define LDCVALUE_RPMIN                  0x3A

#define LDCFREQUENCY_EXT                8                       //the frequency of extern clock or crystal;8MHz
#define LDCRESPONSE_TIME                6144                    //response time is  Bit 2:0 in the LDC Configuration
                                                                //register 000:reserved,001:reserved,010:192
                                                                //011:768,100:1536,101:3072,111:6144
                                                                //when modify this value,you should also change the LDCVALUE_LDCCONFIG
#define LDCPARALLEI_CAP                 100                     //parallel capacitance of the resonator,100pF



#define LDCSPI_RBIT                     0x80
#define LDCSPI_WBIT                     0x00
#define LDCSPI_CS                       8                      //PIN62      
#define LDCSPI_INT                      19                     //PIN18

class CMelodyLDC1000
{
    private:
        volatile bool m_dataready;
        void write(uint8_t regAddr,uint8_t data);
        uint8_t read(uint8_t regAddr);
    public:
       void begin();
       void interruptHandle(void);
       bool available(void);
       uint16_t getProximity();
       uint32_t getFrequency();
       float calcInductance(uint32_t frequency);
       uint8_t getDeviceID();
       uint8_t getStatus();
};
extern CMelodyLDC1000 MelodyLDC1000;
extern "C" void DataReadyIntHandle(void);
#endif /*__MELODY_LDC1000_H__*/