#include <stdbool.h>
#include <stdint.h>
#include <Energia.h>
#include "Melody_LED.h"

static const uint8_t Maxduty = 255;                       //PWM占空比最大,analogWrite最大接收值255
static const uint8_t Minduty = 0;                         //PWM占空比最小

CMelodyLED::CMelodyLED()
{
    m_bright = 0;
}

CMelodyLED::CMelodyLED(uint8_t bright)
{
    m_bright = bright;
}

/*************************************************************************
 * @brief:  计算输出占空比
 * @param：  bright，LED亮度，百分比数据
 * @return： 输出占空比
 * @description:   在Energia中analogWrite(pin.val),val最大值为255（此时为最大输出占空比）
 **************************************************************************/
uint8_t CMelodyLED::calcOutputDuty(uint8_t bright)
{
    uint16_t duty = 0;
    bright = (bright > Maxbright) ? Maxbright : bright;
    m_bright = bright;
    duty = bright * Maxduty / Maxbright;
    return (uint8_t)duty;
}

/*************************************************************************
 * @brief:  初始化
 * @param： none
 * @return：none
 *************************************************************************/
void CMelodyLED::begin()
{
    begin(m_bright);
}

/*************************************************************************
 * @brief:  初始化
 * @param： bright
 * @return：none
 *************************************************************************/
void CMelodyLED::begin(uint8_t bright)
{
    uint8_t duty = calcOutputDuty(bright);
    analogWrite(LEDport,duty);                            
}

/*************************************************************************
 * @brief:  设置LED亮度
 * @param： bright
 * @return: none
 *************************************************************************/
void CMelodyLED::setBright(uint8_t bright)
{
    analogWrite(LEDport,calcOutputDuty(bright));
}

/**************************************************************************
 * @brief:  获取亮度值
 * @param:  none
 * @return: none
 ***************************************************************************/
uint8_t CMelodyLED::getBright()
{
    return m_bright;
}


CMelodyLED MelodyLED;