#include <stdbool.h>
#include <stdint.h>
#include <Energia.h>
#include "Wire.h"
#include "Melody_OPT3001.h"

//----------private methods-------------------//
/*******************************************************************************
 * @brief:  写寄存器数据
 * @param： regAddress,寄存器地址
 *          data,待写入数据
 * @return： none
 ********************************************************************************/
void CMelodyOPT3001::write(uint8_t regAddress,uint16_t data)
{
    Wire.beginTransmission(OPTADDRESS);
    Wire.write(regAddress);
    Wire.write(data >> 8);
    Wire.write(data);
    Wire.endTransmission();
}

/********************************************************************************
 * @brief:  读取寄存器数据
 * @param： regAddress,寄存器地址
 * @return：none
 ********************************************************************************/
uint16_t CMelodyOPT3001::read(uint8_t regAddress)
{
    Wire.beginTransmission(OPTADDRESS);
    Wire.write(regAddress);
    Wire.endTransmission();

    uint16_t data = 0;
    Wire.requestFrom(OPTADDRESS,2);
    if(Wire.available() >= 2)
    {
        data = Wire.read();
        data = (data << 8) | Wire.read();
    }

    return data;
}
        
//---------public methods---------------------//
/*******************************************************************************
 * @brief:  初始化配置
 * @param：  none
 * @return： none
 *******************************************************************************/
void CMelodyOPT3001::begin(void)
{
    Wire.begin();

    write(OPTREG_COMFIGURATION,OPTVALUE_CONFIGURATION);
}

/*******************************************************************************
 * @brief:  读取Manufacturer ID
 * @param：  none
 * @return：Manufacturer ID
 *******************************************************************************/
uint16_t CMelodyOPT3001::getManufacturerID(void)
{
    return read(OPTREG_MANUFACTURERID);
}

/*******************************************************************************
 * @brief:  读取Device ID
 * @param：  none
 * @return：Device ID
 *******************************************************************************/
uint16_t CMelodyOPT3001::getDeviceID(void)
{
    return read(OPTREG_DEVICEID);
}

/********************************************************************************
 * @brief:  读取感光值
 * @param：  none
 * #return：none
 ********************************************************************************/
float CMelodyOPT3001::getLux(void)
{
    uint16_t value = read(OPTREG_RESULT);

    //计算公式见数据手册P20
    float lux = 0.01 * (1 << ((value & 0xF000) >> 12)) * (value & 0x0FFF);
    return lux;
}

CMelodyOPT3001 MelodyOPT3001;