/***************************************************************
 * 实现方式参考例程SimpleWebServerWiFi.ino
 **************************************************************/

#include <stdint.h>
#include <stdbool.h>
#include <WiFi.h>
#include "../MelodyLED/Melody_LED.h"
#include "../MelodyHDC1080/Melody_HDC1080.h"
#include "../MelodyLDC1000/Melody_LDC1000.h"
#include "../MelodyADXL345/Melody_ADXL345.h"
#include "../MelodyLMT84/Melody_LMT84.h"
#include "../MelodyOPT3001/Melody_OPT3001.h"
#include "../MelodyStepMotor/Melody_StepMotor.h"
#include "Melody_Simplehtml.h"

/*******************************************************************
 * @brief:  开启简单的Web服务,函数使用之前需要开始串口即
 *          需要在Serial.begin()后调用该函数
 * @param： ssid，指向ssid的指针
 *          pwd，指向pwd的指针
 * @return：none
 *******************************************************************/
void beginServer(WiFiServer &server, char *ssid,char *pwd)
{
   Serial.println("Attempting to connect to Network named:");
   Serial.println(ssid);
   
   // Connect to WPA/WPA2 network. Change this line if using open or WEP network:
   WiFi.begin(ssid,pwd);
   while(WiFi.status() != WL_CONNECTED)
   {
      // print dots while we wait to connect
     Serial.print(".");
     delay(300);
   }
   
   Serial.println("\nYou're connecten to the network");
   Serial.println("Wating for an ip address");
   
   while(WiFi.localIP() == INADDR_NONE)
   {
         // print dots while we wait for an ip addresss
     Serial.print(".");
     delay(300);
   }
   
   Serial.println("\nIP Address obtained");

   // print the SSID of the network you're attached to:
   Serial.print("SSID:");
   Serial.println(WiFi.SSID());
  
   // print your WiFi IP address:
   IPAddress ip = WiFi.localIP();
   Serial.print("IP Address:");
   Serial.println(ip);
  
   // print the received signal strength:
   long rssi = WiFi.RSSI();
   Serial.print("signal strength (RSSI):");
   Serial.print(rssi);
   Serial.println(" dBm");
   // print where to go in a browser:
   Serial.print("To see this page in action, open a browser to http://");
   Serial.println(ip);

   Serial.println("Starting webserver on port 80");
   server.begin();                           // start the web server on port 80
   Serial.println("Webserver started!");
}



/******************************************************************
 * @brief:  打印LED模块的html信息
 * @param：  bright 亮度值
 * @return： none
 ******************************************************************/
void printLEDhtml(WiFiClient &client,uint8_t bright)
{
    //HTTP header
    client.println("HTTP/1.1 200 OK");
    client.println("Content-type:text/html");
    client.println();

    //html部分
    client.println("<!DOCTYPE HTML>");
    client.println("<html>");

    client.println("<head>");
    client.println("<title>Energia WiFi Web Server</title>");
    client.println("<script type=\"text/javascript\">");
    client.println("function Limit(){");
    client.println("var value=document.getElementById(\"bright\").value;");
    client.println("if(value<0){document.getElementById(\"bright\").value=0;}");
    client.println("if(value>100){document.getElementById(\"bright\").value=100;}}");
    client.println("</script>");
    client.println("</head>");   

    client.println("<body>");
    client.println("<h1 align=\"center\"><font color=\"red\">Welcome to LED demo</font></h1>");
    client.println("<div align=\"center\">");
    client.println("<form action=\"LED.html\" method=\"get\">");
    client.print("Bright<input type=\"number\" id=\"bright\" name=\"bright\" style=\"width:80px\" oninput=\"Limit()\" value=\"");
    client.print(bright);
    client.println("\"</input>");
    client.println("<input type=\"submit\" value=\"set\"></input>");
    client.println("</form>");
    client.println("</div>");
    client.println("</body>");

    client.println("</html>");
}

/***************************************************************
 * @brief:  处理LED请求信息
 * @param： server
 *          client
 * @return：none
 ***************************************************************/
void handleLEDRequest(WiFiServer &server,WiFiClient &client)
{
    client = server.available();                //侦听客户端连接

    if(client)                                  //new client
    {
        Serial.println("new client");
        String currentLine = "";                //存储接收的数据报文
        while(client.connected())
        {
            if(client.available())
            {
                char c = client.read();         //读取单个字节数据
                Serial.print(c);                //打印接收的数据，方便观察
                //分析
                if(c == '\n')                   //接收完一行，字符结尾：\n\r
                {
                    //接收到空行时表示一次响应完成，进行break while
                    if(currentLine.length() == 0)
                    {
                        break;
                    }
                    //一行数据接收完整后进行删除
                    currentLine = "";
                }
                else if(c != '\r')
                {
                    currentLine += c;
                }

                //判断有效待处理行，其中有包括HTTP字符。当接收到HTTP时（虽然不是该行数据全部接收完）
                //进行分析处理
                if(currentLine.endsWith("HTTP"))
                {
                    //处理相关信息
                    if(currentLine.substring(0,strlen("GET / ")) == "GET / ")
                    {
                        printLEDhtml(client,MelodyLED.getBright());
                    }
                    else if(currentLine.substring(0,strlen("GET /LED.html")) == "GET /LED.html")
                    {
                        //首先获取bright数据，然后发送回应包
                        int eq = currentLine.indexOf('=');
                        int ls = currentLine.lastIndexOf(' ');
                        String data = currentLine.substring(eq+1,ls);
                        MelodyLED.setBright(data.toInt());
                        printLEDhtml(client,MelodyLED.getBright());
                    }
                }
            }
        }

        client.stop();
        Serial.println("client disconnected");
    }
}


/*********************************************************************
 * @brief:  打印HDC1080模块的html信息
 * @param：  manufID，manufacturer ID
 *           deviceID,
 *           temperature,温度
 *           humidity,湿度
 * @return：none
 ***********************************************************************/
void printHDC1080html(WiFiClient &client,uint16_t manufID,uint16_t deviceID,float temperature,float humidity)
{
    //HTTP header
    client.println("HTTP/1.1 200 OK");
    client.println("Content-type:text/html");
    client.println("Refresh:5");
    client.println();

    //html部分
    client.println("<!DOCTYPE HTML>");

    client.println("<html>");

    client.println("<head><title>Energia WiFi Web Server</title></head>");
    
    client.println("<body>");
    client.println("<h1 align=\"center\"><font color=\"red\">Welcome to HDC1080 demo</font></h1>");
    client.println("<table align=\"center\">");
    client.print("<tr><td align=\"right\">Manufacturer ID:</td><td><input type=\"text\" value=\"0x");
    client.print(manufID,HEX);
    client.println("\"/></td></tr>");
    client.print("<tr><td align=\"right\">Device ID:</td><td><input type=\"text\" value=\"0x");
    client.print(deviceID,HEX);
    client.println("\"/></td></tr>");
    client.print("<tr><td align=\"right\">Temperature:</td><td><input type=\"text\" value=\"");
    client.print(temperature);
    client.println("\"/></td></tr>");
    client.print("<tr><td align=\"right\">Humidity:</td><td><input type=\"text\" value=\"");
    client.print(humidity);
    client.println("\"/></td></tr>");
    client.println("</table>");
    client.println("</body>");

    client.println("</html>");
}

/*******************************************************************************************
 * @brief:  处理HDC1080请求信息
 * @param： server
 *          client
 * @return：none
 ********************************************************************************************/
void handleHDC1080Request(WiFiServer &server,WiFiClient &client)
{
    client = server.available();                //侦听客户端连接

    if(client)                                  //new client
    {
        Serial.println("new client");           
        String currentLine = "";                //存储接收的数据报文
        while(client.connected())
        {
            if(client.available())
            {
                char c = client.read();         //读取单个字节数据
                Serial.print(c);                //打印接收的数据，方便观察
                //分析
                if(c == '\n')                   //接收完一行，字符结尾：\n\r
                {
                    //接收到空行时表示一次响应完成，进行break while
                    if(currentLine.length() == 0)
                    {
                        break;
                    }
                    //一行数据接收完整后进行删除
                    currentLine = "";
                }
                else if(c != '\r')
                {
                    currentLine += c;
                }

                //判断有效待处理行，其中有包括HTTP字符。当接收到HTTP时（虽然不是该行数据全部接收完）
                //进行分析处理
                if(currentLine.endsWith("HTTP"))
                {
                    //处理有关信息
                    if(currentLine.substring(0,strlen("GET / ")) == "GET / ")
                    {
                        printHDC1080html(client,MelodyHDC1080.getManufacturerID(),MelodyHDC1080.getDeviceID(),
                                         MelodyHDC1080.getTemperature(),MelodyHDC1080.getHumidity());
                    }
                }
            }
        }
        
        client.stop();
        Serial.println("client disconnected");
    }
}

/************************************************************************
 * @brief: 打印LDC1000模块的html信息
 * @param：deviceID
 *         proximity
 *         inductance
 * @return：none
 *************************************************************************/
void printLDC1000html(WiFiClient &client,uint16_t deviceID,uint16_t proximity,float inductance)
{
    //HTTP header
    client.println("HTTP/1.1 200 OK");
    client.println("Content-type:text/html");
    client.println("Refresh:5");
    client.println();

        //html部分
    client.println("<!DOCTYPE HTML>");
    client.println("<html>");

    client.println("<head><title>Energia CC3200 WiFi Web Server</title></head>");

    client.println("<body>");
    client.println("<h1 align=\"center\"><font color=\"red\">Welcome to LDC1000 demo</font></h1>");
    client.println("<table align=\"center\">");
    client.print("<tr><td align=\"right\">Device ID:</td><td><input type=\"text\" value=\"0x");
    client.print(deviceID);
    client.println("\"/></td></tr>");
    client.print("<tr><td align=\"right\">Proximmity:</td><td><input type=\"text\" value=\"");
    client.print(proximity);
    client.println("\"/></td></tr>");
    client.print("<tr><td align=\"right\">Inductance:</td><td><input type=\"text\" value=\"");
    client.print(inductance);
    client.println("\"/></td></tr>");
    client.println("</table>");
    client.println("</body>");

    client.println("</html>");
}


/******************************************************************************
 * @brief:  处理LDC1000的请求
 * @param： server
 *          client
 * @return: none
 ******************************************************************************/
void handleLDC1000Request(WiFiServer &server,WiFiClient &client)
{
    client = server.available();

    if(client)
    {
        Serial.println("new client");
        String currentLine = "";
        while(client.connected())
        {
            if(client.available())
            {
                char c = client.read();                 
                Serial.print(c);

                //分析数据
                if(c == '\n')                               //接收完一行，字符结尾：\n\r
                {
                    //接收到空行，表示接收完全，退出While·
                    if(currentLine.length() == 0)
                    {
                        break;
                    }
                    //一行数据接收完整后进行删除
                    currentLine = "";
                }
                else if(c != '\r')
                {
                    currentLine += c;
                }

                //判断有效待处理行，其中有包括HTTP字符。当接收到HTTP时（虽然不是该行数据全部接收完）
                //进行分析处理
                if(currentLine.endsWith("HTTP"))
                {
                    //处理有关信息
                    if(currentLine.substring(0,strlen("GET / ")) == "GET / ")
                    {
                        printLDC1000html(client,MelodyLDC1000.getDeviceID(),MelodyLDC1000.getProximity(),
                                            MelodyLDC1000.calcInductance(MelodyLDC1000.getFrequency()));
                    }
                }
            }
        }
        
        client.stop();
        Serial.println("client disconnected");
    }
}
/**************************************************************************
 * @brief:  打印LMT84模块的html信息
 * @param： temperature,温度
 * @return: none
 **************************************************************************/
void printLMT84html(WiFiClient &client,float temperature)
{
    //HTTP header
    client.println("HTTP/1.1 200 OK");
    client.println("Content-type:text/html");
    client.println("Refresh:5");
    client.println();

        //html部分
    client.println("<!DOCTYPE HTML>");

    client.println("<html>");

    client.println("<head><title>Energia CC3200 WiFi Web Server</title></head>");

    client.println("<body>");
    client.println("<h1 align=\"center\"><font color=\"red\">Welcome to LMT84 demo</font></h1>");
    client.print("<p align=\"center\">Temperature: <input type=\"text\" value=\"");
    client.print(temperature);
    client.println("(Celsius)\"/></p>");
    client.println("</body>");

    client.println("</html>");
}


/******************************************************************************
 * @brief:  处理LMT84的请求
 * @param： server
 *          client
 * @return: none
 ******************************************************************************/
void handleLMT84Request(WiFiServer &server,WiFiClient &client)
{
    client = server.available();

    if(client)
    {
        Serial.println("new client");
        String currentLine = "";
        while(client.connected())
        {
            if(client.available())
            {
                char c = client.read();                 
                Serial.print(c);

                //分析数据
                if(c == '\n')                               //接收完一行，字符结尾：\n\r
                {
                    //接收到空行，表示接收完全，退出While·
                    if(currentLine.length() == 0)
                    {
                        break;
                    }
                    //一行数据接收完整后进行删除
                    currentLine = "";
                }
                else if(c != '\r')
                {
                    currentLine += c;
                }

                //判断有效待处理行，其中有包括HTTP字符。当接收到HTTP时（虽然不是该行数据全部接收完）
                //进行分析处理
                if(currentLine.endsWith("HTTP"))
                {
                    //处理有关信息
                    if(currentLine.substring(0,strlen("GET / ")) == "GET / ")
                    {
                        printLMT84html(client,MelodyLMT84.getTemperature());
                    }
                }
            }
        }
        
        client.stop();
        Serial.println("client disconnected");
    }
}

/***************************************************************************
 * @brief: 打印ADXL345模块的html信息
 * @param：deviceID
 *          x,X轴加速度
 *          y,Y轴加速度
 *          z，Z轴加速度
 * @return:none
 ***************************************************************************/
void printADXL345html(WiFiClient &client,uint16_t deviceID,int16_t x,int16_t y,int16_t z)
{   
        //HTTP header
    client.println("HTTP/1.1 200 OK");
    client.println("Content-type:text/html");
    client.println("Refresh:5");
    client.println();

        //html部分
    client.println("<!DOCTYPE HTML>");

    client.println("<html>");

    client.println("<head><title>Energia CC3200 WiFi Web Server</title></head>");

    client.println("<body>");
    client.println("<h1 align=\"center\"><font color=\"red\">Welcome to ADXL345 demo</font></h1>");
    client.println("<table align=\"center\" border=\"1\" width=\"200px\">");
    client.println("<tr align=\"center\"><td>Device ID</td><td>Accelerate</td></tr>");
    client.println("<tr align=\"center\">");
    client.print("<td><p>0x");
    client.print(deviceID,HEX);
    client.println("</p></td>");
    client.println("<td>");
    client.print("<p>X:");
    client.print(x);
    client.println("</p>");
    client.print("<p>Y:");
    client.print(y);
    client.println("</p>");
    client.print("<p>Z:");
    client.print(z);
    client.println("</p>");
    client.println("</td>");
    client.println("</table>");
    client.println("</body>");

    client.println("</html>");
}

/******************************************************************************
 * @brief:  处理LMT84的请求
 * @param： server
 *          client
 * @return: none
 ******************************************************************************/
void handleADXL345Request(WiFiServer &server,WiFiClient &client)
{
    client = server.available();

    if(client)
    {
        Serial.println("new client");
        String currentLine = "";
        while(client.connected())
        {
            if(client.available())
            {
                char c = client.read();                 
                Serial.print(c);

                //分析数据
                if(c == '\n')                               //接收完一行，字符结尾：\n\r
                {
                    //接收到空行，表示接收完全，退出While·
                    if(currentLine.length() == 0)
                    {
                        break;
                    }
                    //一行数据接收完整后进行删除
                    currentLine = "";
                }
                else if(c != '\r')
                {
                    currentLine += c;
                }

                //判断有效待处理行，其中有包括HTTP字符。当接收到HTTP时（虽然不是该行数据全部接收完）
                //进行分析处理
                if(currentLine.endsWith("HTTP"))
                {
                    //处理有关信息
                    if(currentLine.substring(0,strlen("GET / ")) == "GET / ")
                    {
                         printADXL345html(client,MelodyADXL345.getDeviceID(),MelodyADXL345.getXAccelerate(),
                                         MelodyADXL345.getYAccelerate(),MelodyADXL345.getZAccelerate());
                    }
                }
            }
        }
        
        client.stop();
        Serial.println("client disconnected");
    }
}
/**************************************************************************
 * @brief: 打印步进电机模块的html信息
 * @param： direction，方向
 *          speed，速度
 * @return：none
 **************************************************************************/
void printStepMotorhtml(WiFiClient &client,bool direction,uint16_t speed)
{
        //HTTP header
    client.println("HTTP/1.1 200 OK");
    client.println("Content-type:text/html");
    client.println();

        //html部分
    client.println("<html>");

    client.println("<head>");
    client.println("<title>Energia CC3200 WiFi Web Server</title>");
    client.println("<script type=\"text/javascript\">function Limit(){");
    client.println("var value=document.getElementById(\"speed\").value;");
    client.println("if(value<0){document.getElementById(\"speed\").value=0;}");
    client.println("if(value>10){document.getElementById(\"speed\").value=10;}}");
    client.println("</script>");
    client.println("</head>");

    client.println("<body>");
    client.println("<h1 align=\"center\"><font color=\"red\">Welcome to StepMotor Demo</font></h1>");
    client.println("<form action=\"StepMotor.html\" method=\"get\">");
    client.println("<table border=\"1\" width=\"200px\" align=\"center\">");
    client.println("<tr><td align=\"center\">Direction:</td>");
    client.println("<td align=\"right\">");
    client.print("forward:<input type=\"radio\"");
    if(direction)
    {
        client.print("checked=\"checked\"");
    }
    client.println("name=\"Direction\" value=\"forward\"/>");
    client.println("backward:<input type=\"radio\"");
    if(!direction)
    {
        client.print("checked=\"checked\"");
    }
    client.println("name=\"Direction\" value=\"backward\"/>");
    client.println("</td></tr>");
    client.println("<tr align=\"center\"><td>Speed:</td>");
    client.print("<td><input type=\"number\" id=\"speed\" name=\"speed\" oninput=\"Limit()\" style=\"text-align:center\" value=\"");
    client.print(speed);
    client.println("\"/></td></tr>");
    client.println("<tr align=\"center\"><td></td>");
    client.println("<td><input type=\"submit\" value=\"set\"/></td></tr>");
    client.println("<table>");
    client.println("</form>");
    client.println("</body>");

    client.println("</html>");
}

/**********************************************************************************
 * @brief:  处理StepMotor请求
 * @param： server
 *          client
 * @return：none
 ***********************************************************************************/
void handleStepMotorRequest(WiFiServer &server,WiFiClient &client)
{
    client = server.available();

    if(client)
    {
        Serial.println("new client");
        String currentLine = "";
        while(client.connected())
        {
            if(client.available())
            {
                char c = client.read();                 
                Serial.print(c);

                //分析数据
                if(c == '\n')                               //接收完一行，字符结尾：\n\r
                {
                    //接收到空行，表示接收完全，退出While·
                    if(currentLine.length() == 0)
                    {
                        break;
                    }
                    //一行数据接收完整后进行删除
                    currentLine = "";
                }
                else if(c != '\r')
                {
                    currentLine += c;
                }

                //判断有效待处理行，其中有包括HTTP字符。当接收到HTTP时（虽然不是该行数据全部接收完）
                //进行分析处理
                if(currentLine.endsWith("HTTP"))
                {
                    //处理有关信息
                    if(currentLine.substring(0,strlen("GET / ")) == "GET / ")
                    {
                         printStepMotorhtml(client,MelodyStepMotor.getDirection(),MelodyStepMotor.getSpeed());
                    }
                    else if(currentLine.substring(0,strlen("GET /StepMotor.html")) == "GET /StepMotor.html")
                    {
                        //首先获取bright数据，然后发送回应包
                        //分成两个部分
                        int start = currentLine.indexOf('?');
                        int mid = currentLine.indexOf('&');

                        //前一个部分，表示方向
                        String data = currentLine.substring(start+1,mid);
                        int eq = data.indexOf('=');
                        if(data.substring(eq+1,data.length()) == "forward")
                        {
                            MelodyStepMotor.changeDirection(true);
                        }
                        else
                        {
                            MelodyStepMotor.changeDirection(false);
                        }

                        //后一个部分，表示速度
                        data = currentLine.substring(mid+1,currentLine.length()-strlen(" HTTP"));     
                        eq = data.indexOf('=');
                        String str_speed = data.substring(eq+1,data.length());
                        MelodyStepMotor.changeSpeed(str_speed.toInt());
                        printStepMotorhtml(client,MelodyStepMotor.getDirection(),MelodyStepMotor.getSpeed());
                    }
                }
            }
        }
        
        client.stop();
        Serial.println("client disconnected");
    }
}

/******************************************************************************************
* @brief:   打印OPT3001的html
* @param：  client
*           manfID： manfacturer ID
*           deviceID  Device ID 
*           lux 
* @return：none
 ******************************************************************************************/
void printOPT3001html(WiFiClient &client,uint16_t manufID,uint16_t deviceID,float lux)
{
            //HTTP header
    client.println("HTTP/1.1 200 OK");
    client.println("Content-type:text/html");
    client.println("Refresh:5");
    client.println();

        //html部分
    client.println("<!DOCTYPE HTML>");

    client.println("<html>");

    client.println("<head>");
    client.println("<title>Energia CC3200 WiFi Web Server</title>");
    client.println("<h1 align=\"center\"><font color=\"red\">Welcome to OPT3001 Demo</font></h1>");
    client.println("</head>");

    client.println("<body>");
    client.println("<table align=\"center\">");

    client.println("<tr align=\"right\">");
    client.println("<td>Manufacturer ID:</td>");
    client.print("<td><input type=\"text\" id=\"manufID\"  value=\"0x");
    client.print(manufID,HEX);
    client.println("\" /></td>");
    client.println("</tr>");

    client.println("<tr align=\"right\">");
    client.println("<td>Device ID:</td>");
    client.print("<td><input type=\"text\" id=\"DeviceID\" value=\"0x");
    client.print(deviceID,HEX);
    client.println("\" /></td>");
    client.println("</tr>");

    client.println("<tr align=\"right\">");
    client.println("<td>Lux Value:</td>");
    client.print("<td><input type=\"text\" id=\"Lux\" value=\"");
    client.print(lux);
    client.println("\" /></td>");
    client.println("</tr>");

    client.println("</table>");
    client.println("</body>");

    client.println("</html>");
    
}

/********************************************************************************
 * @brief:  处理OPT3001请求
 * @param： server
 *          client
 * @return： none
 ********************************************************************************/
void handleOPT3001Request(WiFiServer &server,WiFiClient &client)
{
    client = server.available();

    if(client)
    {
        Serial.println("new client");
        String currentLine = "";
        while(client.connected())
        {
            if(client.available())
            {
                char c = client.read();                 
                Serial.print(c);

                //分析数据
                if(c == '\n')                               //接收完一行，字符结尾：\n\r
                {
                    //接收到空行，表示接收完全，退出While·
                    if(currentLine.length() == 0)
                    {
                        break;
                    }
                    //一行数据接收完整后进行删除
                    currentLine = "";
                }
                else if(c != '\r')
                {
                    currentLine += c;
                }

                //判断有效待处理行，其中有包括HTTP字符。当接收到HTTP时（虽然不是该行数据全部接收完）
                //进行分析处理
                if(currentLine.endsWith("HTTP"))
                {
                    //处理有关信息
                    if(currentLine.substring(0,strlen("GET / ")) == "GET / ")
                    {
                         printOPT3001html(client,MelodyOPT3001.getManufacturerID(),MelodyOPT3001.getDeviceID(),
                                            MelodyOPT3001.getLux());
                    }
                }
            }
        }
        
        client.stop();
        Serial.println("client disconnected");
    }
}

/*
//---------------------------------------------------------------------------------
// @brief: 处理html请求
// @param: server
//         client
//         module:模块
// @return：none
//----------------------------------------------------------------------------------
void handleHtmlRequest(WiFiServer &server,WiFiClient client,e_MelodyModule module)
{
    client = server.available();                //侦听客户端连接

    if(client)                                  //new client
    {
        Serial.println("new client");
        String currentLine = "";                //存储接收的数据报文
        while(client.connected())
        {
            if(client.available())
            {
                char c = client.read();         //读取单个字节数据
                Serial.print(c);                //打印接收的数据，方便观察
                //分析
                if(c == '\n')                   //接收完一行，字符结尾：\n\r
                {
                    //接收到空行时表示一次响应完成，进行break while
                    if(currentLine.length() == 0)
                    {
                        break;
                    }
                    //一行数据接收完整后进行删除
                    currentLine = "";
                }
                else if(c != '\r')
                {
                    currentLine += c;
                }

                //判断有效待处理行，其中有包括HTTP字符。当接收到HTTP时（虽然不是该行数据全部接收完）
                //进行分析处理
                if(currentLine.endsWith("HTTP"))
                {
                    //处理相关信息
                    if(currentLine.substring(0,strlen("GET / ")) == "GET / ")
                    {
                        switch(module)
                        {
                            case MELODYLED:
                                printLEDhtml(client,MelodyLED.getBright());
                            break;
                            case MELODYHDC1080:
                                 printHDC1080html(client,MelodyHDC1080.getManufacturerID(),MelodyHDC1080.getDeviceID(),
                                         MelodyHDC1080.getTemperature(),MelodyHDC1080.getHumidity());
                            break;
                            case MELODYLDC1000:
                                printLDC1000html(client,MelodyLDC1000.getDeviceID(),MelodyLDC1000.getProximity(),
                                            MelodyLDC1000.calcInductance(MelodyLDC1000.getFrequency()));
                            break;
                            case MELODYLMT84:
                                printLMT84html(client,MelodyLMT84.getTemperature());
                            break;
                            case MELODYADXL345:
                                 printADXL345html(client,MelodyADXL345.getDeviceID(),MelodyADXL345.getXAccelerate(),
                                         MelodyADXL345.getYAccelerate(),MelodyADXL345.getZAccelerate());
                            break;
                            case MELODYSTEPMOTOR:
                            break;
                            default:
                            break;
                        }
                        
                    }
                    else if(currentLine.substring(0,strlen("GET /LED.html")) == "GET /LED.html")
                    {
                        //首先获取bright数据，然后发送回应包
                        int eq = currentLine.indexOf('=');
                        int ls = currentLine.lastIndexOf(' ');
                        String data = currentLine.substring(eq+1,ls);
                        MelodyLED.setBright(data.toInt());
                        printLEDhtml(client,MelodyLED.getBright());
                    }
                }
            }
        }

        client.stop();
        Serial.println("client disconnected");
    }
}
*/