#include <Energia.h>
#include <stdbool.h>
#include <stdint.h>
#include <driverlib/prcm.h>
#include <driverlib/rom_map.h>
#include <driverlib/pin.h>
#include <driverlib/Timer.h>
#include <driverlib/interrupt.h>
#include <inc/hw_ints.h>
#include <inc/hw_memmap.h>
#include <inc/hw_gprcm.h>
#include "utility/timer_if.h"
#include "Melody_StepMotor.h" 

/*
#define DRIVER_1_L          digitalWrite(PIN_AIN1,LOW)                  //PWM1       A1
#define DRIVER_1_H          digitalWrite(PIN_AIN1,HIGH)

#define DRIVER_2_L          digitalWrite(PIN_BIN2,LOW)                  //PWM3       B2
#define DRIVER_2_H          digitalWrite(PIN_BIN2,HIGH)

#define DRIVER_3_L          digitalWrite(PIN_AIN2,LOW)                  //PWM2       A2
#define DRIVER_3_H          digitalWrite(PIN_AIN2,HIGH)

#define DRIVER_4_L          digitalWrite(PIN_BIN1,LOW)                  //PWM4       B1
#define DRIVER_4_H          digitalWrite(PIN_BIN1,HIGH)
*/

#define DRIVER_4_L          digitalWrite(PIN_AIN1,LOW)                  //PWM1       A1
#define DRIVER_4_H          digitalWrite(PIN_AIN1,HIGH)

#define DRIVER_3_L          digitalWrite(PIN_BIN2,LOW)                  //PWM3       B2
#define DRIVER_3_H          digitalWrite(PIN_BIN2,HIGH)

#define DRIVER_2_L          digitalWrite(PIN_AIN2,LOW)                  //PWM2       A2
#define DRIVER_2_H          digitalWrite(PIN_AIN2,HIGH)

#define DRIVER_1_L          digitalWrite(PIN_BIN1,LOW)                  //PWM4       B1
#define DRIVER_1_H          digitalWrite(PIN_BIN1,HIGH)

//--------private method--------------//
/***************************************************************
 * @brief:初始化设置定时器
 * @param：none
 * @return：none
 **************************************************************/
void CMelodyStepMotor::timerInit(void)
{

    pinMode(PIN_AIN1,OUTPUT);
    pinMode(PIN_AIN2,OUTPUT);
    pinMode(PIN_BIN1,OUTPUT);
    pinMode(PIN_BIN2,OUTPUT);
    DRIVER_1_L;
    DRIVER_2_L;
    DRIVER_3_L;
    DRIVER_4_L;

    Timer_IF_Init(PRCM_TIMERA0,TIMERA0_BASE,TIMER_CFG_PERIODIC,TIMER_A,0);
    Timer_IF_IntSetup(TIMERA0_BASE,TIMER_A,timerInterruptHandler);
    Timer_IF_Start(TIMERA0_BASE,TIMER_A,PERIODIC_TEST_CYCLES / 2 / m_speed);
}

//---------public method--------------//
/*************************************************************
 * @brief:初始化设置
 * @param：none
 * @return: none
 *************************************************************/
void CMelodyStepMotor::begin()
{
    begin(MINSPEED,true,0);
}

/*************************************************************
 * @brief:初始化设置
 * @param：speed,初始速度
 * @return: none
 *************************************************************/
void CMelodyStepMotor::begin(uint8_t speed)
{   
    begin(speed,true,0);
}

/*************************************************************
 * @brief:初始化设置
 * @param：speed,初始速度
 *         direction,初始方向
 * @return: none
 *************************************************************/
void CMelodyStepMotor::begin(uint8_t speed,bool direction)
{
    begin(speed,direction,0);
}

/*************************************************************
 * @brief:初始化设置
 * @param：speed,初始速度
 *         direction,初始方向
 *         step,初始叶轮位置
 * @return: none
 *************************************************************/
void CMelodyStepMotor::begin(uint8_t speed,bool direction,uint8_t step)
{
    setBeginStep(step);

    if(speed <= MINSPEED)
    {
        m_speed = MINSPEED;
    }
    else if(speed >= MAXSPEED)
    {
        m_speed = MAXSPEED;
    }
    else
    {
        m_speed = speed;
    }

    m_direction = direction;

    timerInit();
}

/****************************************************************
 * @brief: 改变速度
 * @param:  speed,速度
 * @return：none
 ****************************************************************/
void CMelodyStepMotor::changeSpeed(uint8_t speed)
{
    if(speed <= MINSPEED)
    {
        m_speed = MINSPEED;
    }
    else if(speed >= MAXSPEED)
    {
        m_speed = MAXSPEED;
    }
    else
    {
        m_speed = speed;
    }

    Timer_IF_ReLoad(TIMERA0_BASE,TIMER_A,PERIODIC_TEST_CYCLES / m_speed);
}

/*******************************************************************
 * @brief:  获取速度
 * @param：none
 * @param：速度
 *******************************************************************/
uint8_t CMelodyStepMotor::getSpeed(void)
{
    return m_speed;
}

/*******************************************************************
 * @brief:  改变方向
 * @brief:  direction,方向
 * @return：none
 ********************************************************************/
void CMelodyStepMotor::changeDirection(bool direction)
{
    m_direction = direction;
}

/*********************************************************************
 * @brief:  获取方向
 * @param:  none
 * @return: 方向
 ********************************************************************/
bool CMelodyStepMotor::getDirection(void)
{
    return m_direction;
}

/*******************************************************************
 * @brief:  获取步进值
 * @param： none
 * @return: steps
 *******************************************************************/
uint8_t CMelodyStepMotor::getSteps(void)
{
    return m_step;                      //在InterruptHandler中限制在0~19.
}

/********************************************************************
 * @brief:   设置启动时叶轮对应位置
 * @param：  step，启动时位置，0~19
 * @return：none
 *********************************************************************/
void CMelodyStepMotor::setBeginStep(uint8_t step)
{
    m_step = step;
}

/***********************************************************************
 * @brief：中断服务函数,实现步进电机序列
 * @param：none
 * @return：none
 ************************************************************************/
void CMelodyStepMotor::InterruptHandler(void)
{
    Timer_IF_InterruptClear(TIMERA0_BASE);
    uint8_t m_status = m_step % 4;
    switch(m_status)
    {
        case 0:
             DRIVER_1_H;DRIVER_2_L;DRIVER_3_L;DRIVER_4_L;
        break;
        case 1:
             DRIVER_1_L;DRIVER_2_H;DRIVER_3_L;DRIVER_4_L;
        break;
        case 2:
            DRIVER_1_L;DRIVER_2_L;DRIVER_3_H;DRIVER_4_L;
        break;
        case 3:
            DRIVER_1_L;DRIVER_2_L;DRIVER_3_L;DRIVER_4_H;
        break;
        default:
        break;
    }

    if(m_direction)
    {        
        ++m_step;
    }
    else
    {
        --m_step;
    }


    if(m_step >= MAXSTEPS)
    {
        m_step = 0;
    }
    if(m_step < 0)
    {
        m_step = MAXSTEPS - 1;
    }
}

CMelodyStepMotor MelodyStepMotor;
/***********************************************************************
 * @brief：中断服务函数 C, 调用CMelodyStepMotor中的InterruptHandler成员函数
 * @param：none
 * @return：none
 ************************************************************************/
void timerInterruptHandler(void)
{
    MelodyStepMotor.InterruptHandler();
}

